@@ -1,34 +1,35 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# HexView.py
-#
-# Extended by Wang Lu
-# Added editing and cursor moving stuff
-# Port to GTK 3
-# Copyright (C) 2010,2011,2013 WANG Lu <coolwanglu@gmail.com>
-#
-# First version
-# Copyright (C) 2008, 2009 Adriano Monteiro Marques
-# Author: Francesco Piccinno <stack.box@gmail.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+"""
+    HexView: memory editor with hex and ascii output
+
+    Extended by Wang Lu and Sebastian Parschauer
+    * Added editing and cursor moving stuff
+    * Port to GTK 3
+    Copyright (C) 2010,2011,2013 WANG Lu <coolwanglu@gmail.com>
+    Copyright (C) 2015 Sebastian Parschauer <s.parschauer@gmx.de>
+
+    First version
+    Copyright (C) 2008, 2009 Adriano Monteiro Marques
+    Author: Francesco Piccinno <stack.box@gmail.com>
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""
 
 from gi.repository import Gtk
 from gi.repository import Gdk
 from gi.repository import Pango
 from gi.repository import GObject
+from gi.repository import GLib
 
 class BaseText(Gtk.TextView):
     __gtype_name__ = 'BaseText'
@@ -38,7 +39,7 @@ class BaseText(Gtk.TextView):
         self.buffer = self.get_buffer()
 
         self._parent = parent
-        self.modify_font(Pango.FontDescription(parent.font))
+        self.override_font(Pango.FontDescription(parent.font))
         self.set_editable(False)
         self.texttag = self.buffer.create_tag(None)
 
@@ -210,7 +211,7 @@ class AsciiText(BaseText):
         output = []
 
         convert = lambda i: "".join(
-            [(x in AsciiText._printable) and (x) or ('.') for x in list(i)])
+            [chr(x) if (chr(x) in AsciiText._printable) else ('.') for x in list(i)])
 
         for i in range(tot_lines):
             if i * bpl + bpl > len(txt):
@@ -414,7 +415,7 @@ class HexText(BaseText):
             tot_lines += 1
 
         output = []
-        convert = lambda x: '%02X'%(ord(x),)
+        convert = lambda x: '%02X'%(x,)
 
         for i in range(tot_lines):
             if i * bpl + bpl > len(txt):
@@ -495,7 +496,7 @@ class HexView(Gtk.Box):
     }
 
     def __init__(self):
-        super(HexView, self).__init__(False, 4)
+        super(HexView, self).__init__(homogeneous=False, spacing=4)
         self.set_border_width(4)
 
         self._bpl = 16
@@ -544,7 +545,7 @@ class HexView(Gtk.Box):
     # select the byte at addr
     # set focus
     def show_addr(self, addr):
-        GObject.idle_add(self.show_addr_helper, addr)
+        GLib.idle_add(self.show_addr_helper, addr)
 
     def show_addr_helper(self, addr):
         off = addr - self._base_addr
@@ -598,7 +599,7 @@ class HexView(Gtk.Box):
     def set_payload(self, val):
         self._payload = val
 
-        for view in (self.offset_text, self.hex_text, self.ascii_text):
+        for view in {self.offset_text, self.hex_text, self.ascii_text}:
             # Invalidate previous iters
             if hasattr(view, 'prev_start'):
                 view.prev_start = None
@@ -615,8 +616,8 @@ class HexView(Gtk.Box):
             desc = Pango.FontDescription(val)
             self._font = val
 
-            for view in (self.offset_text, self.hex_text, self.ascii_text):
-                view.modify_font(desc)
+            for view in {self.offset_text, self.hex_text, self.ascii_text}:
+                view.override_font(desc)
         except Exception:
             pass
 
